@@ -352,7 +352,7 @@ enum { CONTINUE_ITERATING, STOP_ITERATING };
 */
 
 
-#define KICKSHAW_VERSION "1.1.161"
+#define KICKSHAW_VERSION "1.1.162"
 #define RELEASED_IN "2025"
 
 #define TREEVIEW_COLUMN_OFFSET NUMBER_OF_TS_ELEMENTS - NUMBER_OF_COLUMNS
@@ -521,7 +521,7 @@ typedef struct {
 
     GtkWidget *about;
     gchar *version_info;
-    gboolean stopped_trying_to_connect_to_server;
+    gboolean stopped_trying_to_connect_to_server, error_msg_in_about_dialog;
 
     gchar *settings_file_actions;
     GPtrArray *settings_menu_items;
